==> igloo_0_1_2.zip: igloo_0_1_2/igloo/sho_view.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include "inc/header.inc.php";

//ACS check
if (!$user_acs->checkPermission($c_acs['arr_acs']['resource']['shoutbox'], $c_acs['arr_acs']['privilege']['allow_access'])) { //resourece_id, Priv_id
	header("Location: " . $_SESSION['user_homepage'] . "?" . strip_tags(SID));
	exit;
}


if (isset($_POST['insert_shout'])) {
	$shout->user_id = $me['user_id'];
	$shout->insertShout($frmdata);
	
	if (empty($GLOBALS['igloo_error_log'])) {
		//setup statistics
		require_once($c_node['dir']['class_path'] . 'Statistic.class.php');
		$statistic = new Statistic($db);
		$statistic->user_id = $me['user_id'];
		//update stats
		$total = $shout->getShouts();
		$total = count($total);
		
		$statistic->statistic_type_id = $c_node['statistic']['user']['total_shouts'];
		$statistic->setStatistic($total);
			
		return header("Location: sho_view.php?" . strip_tags(SID));	
		exit;
	}
		
	
	
	
}

$shout->limit=25;
unset($shout->user_id);
$output_shouts = $shout->getShouts();


//move to template
if (!empty($output_shouts)) {
    $body->set('shouts', $output_shouts);
}

include "inc/footer.inc.php";
?>

==> igloo_0_1_6.zip: igloo_0_1_6/igloo/sho_view.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include "inc/header.inc.php";

//ACS check
if (!$user_acs->checkPermission($c_acs['arr_acs']['resource']['shoutbox'], $c_acs['arr_acs']['privilege']['allow_access'])) { //resourece_id, Priv_id
	header("Location: " . $_SESSION['user_homepage'] . "?" . strip_tags(SID));
	exit;
}


if (isset($_POST['insert_shout'])) {
	$shout->user_id = $me['user_id'];
	$shout->insertShout($frmdata);
	
	if (empty($GLOBALS['igloo_error_log'])) {
		//setup statistics
		require_once('class/Statistic.class.php');
		$statistic = new Statistic($db);
		$statistic->user_id = $me['user_id'];
		//update stats
		$total = $shout->getShouts();
		$total = count($total);
		
		$statistic->statistic_type_id = $c_node['statistic']['user']['total_shouts'];
		$statistic->setStatistic($total);
			
		return header("Location: sho_view.php?" . strip_tags(SID));	
		exit;
	}
		
	
	
	
}

$shout->limit=25;
unset($shout->user_id);
$output_shouts = $shout->getShouts();


//move to template
if (!empty($output_shouts)) {
    $body->set('shouts', $output_shouts);
}

include "inc/footer.inc.php";
?>
